magneticalc.Version

# ``magneticalc`.`Version``

module documentation

Version module.

Class | `Version` | Version class.
Constant | `__PYPI_SIMPLE__URL__` | Undocumented
Constant | `__URL__` | Undocumented
Constant | `__VERSION__` | Undocumented

__PYPI_SIMPLE__URL__: `str` =

Undocumented

Value
    'https://pypi.org/simple/magneticalc/'

__URL__: `str` =

Undocumented

Value
    'https://github.com/shredEngineer/MagnetiCalc'

__VERSION__: `str` =

Undocumented

Value
    'v1.18.0'